﻿using Contact.API.Model;
using Contact.API.ViewModel;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;

namespace Contact.API.Controllers;

[Route("api/v1/[controller]")]
[ApiController]
public class ContactController : ControllerBase
{
    private readonly ApplicationDBContext _context;

    public ContactController(ApplicationDBContext context)
    {
        this._context = context ?? throw new ArgumentNullException(nameof(context));
    }

    [HttpPost]
    [Route("CreateContects")]
    public async Task<IActionResult> PostQuery([FromBody]ContactViewModel model)
    {
        if(!ModelState.IsValid)
            return BadRequest(ModelState);

        var result = await _context.Contacts.AddAsync(new Model.Contact
        {
            Name = model.Name,
            Email = model.Email,
            Message = model.Query ??= string.Empty
        });
        return Created(string.Empty, result);
    }

    [HttpGet]
    [Route("GetContacts")]
    public async Task<List<ContactViewModel>> GetContacts()
    {
        var result = await _context.Contacts.Select(a => new ContactViewModel
        {
            Email = a.Email,
            Name = a.Name,
            Query = a.Message
        }).ToListAsync();
        return result;
    }
}
